@@ -3,7 +3,8 @@
 use Net::Rendezvous;
 
 my $res = new Net::Rendezvous($ARGV[0]);
-$res->discover;
+print $res->domain($ARGV[1]), "\n";
+print $res->discover;
 
 foreach $entry ( $res->entries ) {
 	printf "%s %s:%s\n",  $entry->name, $entry->hostname, $entry->port;
